Daemon rucio-reaper — Rucio 1.2 documentation

# Daemon rucio-reaper

    usage: rucio-reaper [-h] [--run-once] [--total-workers TOTAL_WORKERS]
                        [--threads-per-worker THREADS_PER_WORKER]
                        [--chunk-size CHUNK_SIZE] [--scheme SCHEME] [--greedy]
                        [--exclude-rses EXCLUDE_RSES]
                        [--include-rses INCLUDE_RSES] [--rses RSES [RSES ...]]
                        [--delay-seconds DELAY_SECONDS]

## Named Arguments

`--run-once` | One iteration only Default: False
`--total-workers`
| Total number of workers per process Default: 1
`--threads-per-worker`
| Total number of threads created by each worker
`--chunk-size` | Chunk size Default: 10
`--scheme` | Force the reaper to use a particular protocol, e.g., mock.
`--greedy` | Greedy mode Default: False
`--exclude-rses` | RSEs expression to exclude RSEs
`--include-rses` | RSEs expression to include RSEs
`--rses` | List of RSEs
`--delay-seconds`
| Delay to retry failed deletion Default: 3600